summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/ui
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kopete/protocols/jabber/ui
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/jabber/ui')
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberbrowse.cpp2
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberbrowse.h2
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberchangepassword.cpp8
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberchangepassword.h2
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberchatjoin.cpp4
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberchatjoin.h2
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberchatroomslist.cpp4
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberchatroomslist.h2
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberregister.cpp2
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberregister.h2
-rw-r--r--kopete/protocols/jabber/ui/dlgjabbersendraw.cpp4
-rw-r--r--kopete/protocols/jabber/ui/dlgjabbersendraw.h2
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberservices.cpp2
-rw-r--r--kopete/protocols/jabber/ui/dlgjabberservices.h6
-rw-r--r--kopete/protocols/jabber/ui/dlgjabbervcard.cpp6
-rw-r--r--kopete/protocols/jabber/ui/dlgjabbervcard.h2
-rw-r--r--kopete/protocols/jabber/ui/jabberaddcontactpage.cpp2
-rw-r--r--kopete/protocols/jabber/ui/jabberaddcontactpage.h4
-rw-r--r--kopete/protocols/jabber/ui/jabberchooseserver.cpp6
-rw-r--r--kopete/protocols/jabber/ui/jabberchooseserver.h2
-rw-r--r--kopete/protocols/jabber/ui/jabbereditaccountwidget.cpp4
-rw-r--r--kopete/protocols/jabber/ui/jabbereditaccountwidget.h2
-rw-r--r--kopete/protocols/jabber/ui/jabberregisteraccount.cpp20
-rw-r--r--kopete/protocols/jabber/ui/jabberregisteraccount.h2
24 files changed, 47 insertions, 47 deletions
diff --git a/kopete/protocols/jabber/ui/dlgjabberbrowse.cpp b/kopete/protocols/jabber/ui/dlgjabberbrowse.cpp
index 22c228c7..d130fa97 100644
--- a/kopete/protocols/jabber/ui/dlgjabberbrowse.cpp
+++ b/kopete/protocols/jabber/ui/dlgjabberbrowse.cpp
@@ -30,7 +30,7 @@
#include "jabberformtranslator.h"
#include "dlgjabberbrowse.h"
-dlgJabberBrowse::dlgJabberBrowse (JabberAccount *account, const XMPP::Jid & jid, TQWidget * tqparent, const char *name):dlgBrowse (tqparent, name)
+dlgJabberBrowse::dlgJabberBrowse (JabberAccount *account, const XMPP::Jid & jid, TQWidget * parent, const char *name):dlgBrowse (parent, name)
{
m_account = account;
diff --git a/kopete/protocols/jabber/ui/dlgjabberbrowse.h b/kopete/protocols/jabber/ui/dlgjabberbrowse.h
index 85b67fb9..57549852 100644
--- a/kopete/protocols/jabber/ui/dlgjabberbrowse.h
+++ b/kopete/protocols/jabber/ui/dlgjabberbrowse.h
@@ -38,7 +38,7 @@ class dlgJabberBrowse:public dlgBrowse
TQ_OBJECT
public:
- dlgJabberBrowse (JabberAccount *account, const XMPP::Jid & jid, TQWidget * tqparent = 0, const char *name = 0);
+ dlgJabberBrowse (JabberAccount *account, const XMPP::Jid & jid, TQWidget * parent = 0, const char *name = 0);
~dlgJabberBrowse ();
private slots:
diff --git a/kopete/protocols/jabber/ui/dlgjabberchangepassword.cpp b/kopete/protocols/jabber/ui/dlgjabberchangepassword.cpp
index ec7d1d10..948a594e 100644
--- a/kopete/protocols/jabber/ui/dlgjabberchangepassword.cpp
+++ b/kopete/protocols/jabber/ui/dlgjabberchangepassword.cpp
@@ -30,8 +30,8 @@
#include "jabberaccount.h"
#include "dlgchangepassword.h"
-DlgJabberChangePassword::DlgJabberChangePassword ( JabberAccount *account, TQWidget *tqparent, const char *name )
- : KDialogBase ( tqparent, name, true, i18n("Change Jabber Password"),
+DlgJabberChangePassword::DlgJabberChangePassword ( JabberAccount *account, TQWidget *parent, const char *name )
+ : KDialogBase ( parent, name, true, i18n("Change Jabber Password"),
KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true )
{
@@ -116,7 +116,7 @@ void DlgJabberChangePassword::slotChangePasswordDone ()
if ( task->success () )
{
- KMessageBox::queuedMessageBox ( dynamic_cast<TQWidget*>(tqparent()), KMessageBox::Information,
+ KMessageBox::queuedMessageBox ( dynamic_cast<TQWidget*>(parent()), KMessageBox::Information,
i18n ( "Your password has been changed successfully. Please note that the change may not be instantaneous. If you have problems logging in with your new password, please contact the administrator." ),
i18n ( "Jabber Password Change" ) );
@@ -124,7 +124,7 @@ void DlgJabberChangePassword::slotChangePasswordDone ()
}
else
{
- KMessageBox::queuedMessageBox ( dynamic_cast<TQWidget*>(tqparent()), KMessageBox::Sorry,
+ KMessageBox::queuedMessageBox ( dynamic_cast<TQWidget*>(parent()), KMessageBox::Sorry,
i18n ( "Your password could not be changed. Either your server does not support this feature or the administrator does not allow you to change your password." ) );
}
diff --git a/kopete/protocols/jabber/ui/dlgjabberchangepassword.h b/kopete/protocols/jabber/ui/dlgjabberchangepassword.h
index 2dd8d8dd..ffeed22b 100644
--- a/kopete/protocols/jabber/ui/dlgjabberchangepassword.h
+++ b/kopete/protocols/jabber/ui/dlgjabberchangepassword.h
@@ -35,7 +35,7 @@ Q_OBJECT
TQ_OBJECT
public:
- DlgJabberChangePassword ( JabberAccount *account, TQWidget *tqparent = 0, const char *name = 0);
+ DlgJabberChangePassword ( JabberAccount *account, TQWidget *parent = 0, const char *name = 0);
~DlgJabberChangePassword();
private slots:
diff --git a/kopete/protocols/jabber/ui/dlgjabberchatjoin.cpp b/kopete/protocols/jabber/ui/dlgjabberchatjoin.cpp
index e24815d5..9d69beae 100644
--- a/kopete/protocols/jabber/ui/dlgjabberchatjoin.cpp
+++ b/kopete/protocols/jabber/ui/dlgjabberchatjoin.cpp
@@ -27,8 +27,8 @@
#include "dlgjabberchatjoin.h"
-dlgJabberChatJoin::dlgJabberChatJoin(JabberAccount *account, TQWidget* tqparent, const char* name) :
-dlgChatJoin(tqparent, name),
+dlgJabberChatJoin::dlgJabberChatJoin(JabberAccount *account, TQWidget* parent, const char* name) :
+dlgChatJoin(parent, name),
m_account(account)
{
setCaption(i18n("Join Jabber Groupchat"));
diff --git a/kopete/protocols/jabber/ui/dlgjabberchatjoin.h b/kopete/protocols/jabber/ui/dlgjabberchatjoin.h
index 6263fd32..1327ba47 100644
--- a/kopete/protocols/jabber/ui/dlgjabberchatjoin.h
+++ b/kopete/protocols/jabber/ui/dlgjabberchatjoin.h
@@ -28,7 +28,7 @@ class dlgJabberChatJoin : public dlgChatJoin
TQ_OBJECT
public:
- dlgJabberChatJoin(JabberAccount *account, TQWidget* tqparent = 0, const char* name = 0);
+ dlgJabberChatJoin(JabberAccount *account, TQWidget* parent = 0, const char* name = 0);
~dlgJabberChatJoin();
/*$PUBLIC_FUNCTIONS$*/
diff --git a/kopete/protocols/jabber/ui/dlgjabberchatroomslist.cpp b/kopete/protocols/jabber/ui/dlgjabberchatroomslist.cpp
index 838eb84f..1803a013 100644
--- a/kopete/protocols/jabber/ui/dlgjabberchatroomslist.cpp
+++ b/kopete/protocols/jabber/ui/dlgjabberchatroomslist.cpp
@@ -21,8 +21,8 @@
#include "dlgjabberchatroomslist.h"
#include "jabberprotocol.h"
-dlgJabberChatRoomsList::dlgJabberChatRoomsList(JabberAccount* account, const TQString& server, const TQString &nick, TQWidget *tqparent, const char *name) :
-dlgChatRoomsList(tqparent, name),
+dlgJabberChatRoomsList::dlgJabberChatRoomsList(JabberAccount* account, const TQString& server, const TQString &nick, TQWidget *parent, const char *name) :
+dlgChatRoomsList(parent, name),
m_account(account) , m_selectedRow(-1) , m_nick(nick)
{
if (!server.isNull())
diff --git a/kopete/protocols/jabber/ui/dlgjabberchatroomslist.h b/kopete/protocols/jabber/ui/dlgjabberchatroomslist.h
index 5bb8b4a9..f16802cc 100644
--- a/kopete/protocols/jabber/ui/dlgjabberchatroomslist.h
+++ b/kopete/protocols/jabber/ui/dlgjabberchatroomslist.h
@@ -24,7 +24,7 @@ class dlgJabberChatRoomsList : public dlgChatRoomsList
TQ_OBJECT
public:
- dlgJabberChatRoomsList(JabberAccount* account, const TQString& server = TQString(), const TQString& nick = TQString(), TQWidget* tqparent = 0, const char* name = 0);
+ dlgJabberChatRoomsList(JabberAccount* account, const TQString& server = TQString(), const TQString& nick = TQString(), TQWidget* parent = 0, const char* name = 0);
~dlgJabberChatRoomsList();
/*$PUBLIC_FUNCTIONS$*/
diff --git a/kopete/protocols/jabber/ui/dlgjabberregister.cpp b/kopete/protocols/jabber/ui/dlgjabberregister.cpp
index 5f6b05a2..8d1324ca 100644
--- a/kopete/protocols/jabber/ui/dlgjabberregister.cpp
+++ b/kopete/protocols/jabber/ui/dlgjabberregister.cpp
@@ -26,7 +26,7 @@
#include "jabberclient.h"
#include "dlgjabberregister.h"
-dlgJabberRegister::dlgJabberRegister (JabberAccount *account, const XMPP::Jid & jid, TQWidget * tqparent, const char *name):dlgRegister (tqparent, name)
+dlgJabberRegister::dlgJabberRegister (JabberAccount *account, const XMPP::Jid & jid, TQWidget * parent, const char *name):dlgRegister (parent, name)
{
m_account = account;
diff --git a/kopete/protocols/jabber/ui/dlgjabberregister.h b/kopete/protocols/jabber/ui/dlgjabberregister.h
index 86100852..bc0bfe44 100644
--- a/kopete/protocols/jabber/ui/dlgjabberregister.h
+++ b/kopete/protocols/jabber/ui/dlgjabberregister.h
@@ -42,7 +42,7 @@ class dlgJabberRegister:public dlgRegister
TQ_OBJECT
public:
- dlgJabberRegister (JabberAccount *account, const XMPP::Jid & jid, TQWidget * tqparent = 0, const char *name = 0);
+ dlgJabberRegister (JabberAccount *account, const XMPP::Jid & jid, TQWidget * parent = 0, const char *name = 0);
~dlgJabberRegister ();
private slots:
diff --git a/kopete/protocols/jabber/ui/dlgjabbersendraw.cpp b/kopete/protocols/jabber/ui/dlgjabbersendraw.cpp
index f16d927a..4b9192dc 100644
--- a/kopete/protocols/jabber/ui/dlgjabbersendraw.cpp
+++ b/kopete/protocols/jabber/ui/dlgjabbersendraw.cpp
@@ -24,8 +24,8 @@
#include <kdebug.h>
#include "jabberclient.h"
-dlgJabberSendRaw::dlgJabberSendRaw ( JabberClient *client, TQWidget *tqparent, const char *name )
- : DlgSendRaw (tqparent, name)
+dlgJabberSendRaw::dlgJabberSendRaw ( JabberClient *client, TQWidget *parent, const char *name )
+ : DlgSendRaw (parent, name)
{
// Connect the GUI elements to things that do stuff
connect (btnSend, TQT_SIGNAL (clicked ()), this, TQT_SLOT (slotSend ()));
diff --git a/kopete/protocols/jabber/ui/dlgjabbersendraw.h b/kopete/protocols/jabber/ui/dlgjabbersendraw.h
index 8a16f3e7..cafd9b94 100644
--- a/kopete/protocols/jabber/ui/dlgjabbersendraw.h
+++ b/kopete/protocols/jabber/ui/dlgjabbersendraw.h
@@ -39,7 +39,7 @@ Q_OBJECT
TQ_OBJECT
public:
- dlgJabberSendRaw ( JabberClient *client, TQWidget * tqparent = 0, const char *name = 0);
+ dlgJabberSendRaw ( JabberClient *client, TQWidget * parent = 0, const char *name = 0);
virtual ~ dlgJabberSendRaw ();
public slots:
diff --git a/kopete/protocols/jabber/ui/dlgjabberservices.cpp b/kopete/protocols/jabber/ui/dlgjabberservices.cpp
index e0e1a315..29b2b617 100644
--- a/kopete/protocols/jabber/ui/dlgjabberservices.cpp
+++ b/kopete/protocols/jabber/ui/dlgjabberservices.cpp
@@ -32,7 +32,7 @@
#include "dlgjabberservices.moc"
-dlgJabberServices::dlgJabberServices (JabberAccount *account, TQWidget *tqparent, const char *name):dlgServices (tqparent, name)
+dlgJabberServices::dlgJabberServices (JabberAccount *account, TQWidget *parent, const char *name):dlgServices (parent, name)
{
m_account = account;
diff --git a/kopete/protocols/jabber/ui/dlgjabberservices.h b/kopete/protocols/jabber/ui/dlgjabberservices.h
index 9672cc55..4ef09d9e 100644
--- a/kopete/protocols/jabber/ui/dlgjabberservices.h
+++ b/kopete/protocols/jabber/ui/dlgjabberservices.h
@@ -37,7 +37,7 @@ class dlgJabberServices:public dlgServices
TQ_OBJECT
public:
- dlgJabberServices (JabberAccount *account, TQWidget *tqparent = 0, const char *name = 0);
+ dlgJabberServices (JabberAccount *account, TQWidget *parent = 0, const char *name = 0);
~dlgJabberServices ();
private slots:
@@ -62,8 +62,8 @@ class dlgJabberServies_item : protected TQObject, public TQListViewItem
Q_OBJECT
TQ_OBJECT
public:
- dlgJabberServies_item( TQListView *tqparent , const TQString &s1 , const TQString &s2 )
- : TQListViewItem(tqparent,s1,s2), can_browse(false) , can_register(false) {}
+ dlgJabberServies_item( TQListView *parent , const TQString &s1 , const TQString &s2 )
+ : TQListViewItem(parent,s1,s2), can_browse(false) , can_register(false) {}
bool can_browse, can_register;
XMPP::Jid jid;
diff --git a/kopete/protocols/jabber/ui/dlgjabbervcard.h b/kopete/protocols/jabber/ui/dlgjabbervcard.h
index 0ab95193..a20f2812 100644
--- a/kopete/protocols/jabber/ui/dlgjabbervcard.h
+++ b/kopete/protocols/jabber/ui/dlgjabbervcard.h
@@ -56,7 +56,7 @@ public:
* @param widget Parent widget.
* @param name widget name.
*/
- dlgJabberVCard (JabberAccount *account, JabberBaseContact *contact, TQWidget * tqparent = 0, const char *name = 0);
+ dlgJabberVCard (JabberAccount *account, JabberBaseContact *contact, TQWidget * parent = 0, const char *name = 0);
~dlgJabberVCard ();
private slots:
diff --git a/kopete/protocols/jabber/ui/jabberaddcontactpage.cpp b/kopete/protocols/jabber/ui/jabberaddcontactpage.cpp
index 0f86a79b..076b92b8 100644
--- a/kopete/protocols/jabber/ui/jabberaddcontactpage.cpp
+++ b/kopete/protocols/jabber/ui/jabberaddcontactpage.cpp
@@ -35,7 +35,7 @@
#include "jabberclient.h"
#include "xmpp_tasks.h"
-JabberAddContactPage::JabberAddContactPage (Kopete::Account * owner, TQWidget * tqparent, const char *name):AddContactPage (tqparent, name)
+JabberAddContactPage::JabberAddContactPage (Kopete::Account * owner, TQWidget * parent, const char *name):AddContactPage (parent, name)
{
(new TQVBoxLayout (this))->setAutoAdd (true);
diff --git a/kopete/protocols/jabber/ui/jabberaddcontactpage.h b/kopete/protocols/jabber/ui/jabberaddcontactpage.h
index bb4e0271..f7c328c2 100644
--- a/kopete/protocols/jabber/ui/jabberaddcontactpage.h
+++ b/kopete/protocols/jabber/ui/jabberaddcontactpage.h
@@ -35,7 +35,7 @@ class JabberAddContactPage:public AddContactPage
TQ_OBJECT
public:
- JabberAddContactPage (Kopete::Account * owner, TQWidget * tqparent = 0, const char *name = 0);
+ JabberAddContactPage (Kopete::Account * owner, TQWidget * parent = 0, const char *name = 0);
~JabberAddContactPage ();
virtual bool validateData ();
virtual bool apply (Kopete::Account *, Kopete::MetaContact *);
@@ -57,7 +57,7 @@ class JabberAddContactPage_there_is_no_possibility_to_add_assync_WORKAROUND : p
{ Q_OBJECT
TQ_OBJECT
public:
- JabberAddContactPage_there_is_no_possibility_to_add_assync_WORKAROUND( JabberTransport * , Kopete::MetaContact *mc, TQObject *tqparent);
+ JabberAddContactPage_there_is_no_possibility_to_add_assync_WORKAROUND( JabberTransport * , Kopete::MetaContact *mc, TQObject *parent);
Kopete::MetaContact *metacontact;
JabberTransport *transport;
public slots:
diff --git a/kopete/protocols/jabber/ui/jabberchooseserver.cpp b/kopete/protocols/jabber/ui/jabberchooseserver.cpp
index b5fef8f3..95272833 100644
--- a/kopete/protocols/jabber/ui/jabberchooseserver.cpp
+++ b/kopete/protocols/jabber/ui/jabberchooseserver.cpp
@@ -30,12 +30,12 @@
#include "dlgjabberchooseserver.h"
#include "jabberregisteraccount.h"
-JabberChooseServer::JabberChooseServer ( JabberRegisterAccount *tqparent, const char *name )
- : KDialogBase ( tqparent, name, true, i18n("Choose Jabber Server"),
+JabberChooseServer::JabberChooseServer ( JabberRegisterAccount *parent, const char *name )
+ : KDialogBase ( parent, name, true, i18n("Choose Jabber Server"),
KDialogBase::Ok | KDialogBase::Cancel )
{
- mParentWidget = tqparent;
+ mParentWidget = parent;
mSelectedRow = -1;
mMainWidget = new DlgJabberChooseServer ( this );
diff --git a/kopete/protocols/jabber/ui/jabberchooseserver.h b/kopete/protocols/jabber/ui/jabberchooseserver.h
index bd74575d..aee2668e 100644
--- a/kopete/protocols/jabber/ui/jabberchooseserver.h
+++ b/kopete/protocols/jabber/ui/jabberchooseserver.h
@@ -42,7 +42,7 @@ Q_OBJECT
TQ_OBJECT
public:
- JabberChooseServer ( JabberRegisterAccount *tqparent = 0, const char *name = 0);
+ JabberChooseServer ( JabberRegisterAccount *parent = 0, const char *name = 0);
~JabberChooseServer();
diff --git a/kopete/protocols/jabber/ui/jabbereditaccountwidget.cpp b/kopete/protocols/jabber/ui/jabbereditaccountwidget.cpp
index 2b5ad749..758322cf 100644
--- a/kopete/protocols/jabber/ui/jabbereditaccountwidget.cpp
+++ b/kopete/protocols/jabber/ui/jabbereditaccountwidget.cpp
@@ -40,8 +40,8 @@
#include "jabberregisteraccount.h"
#include "dlgjabberchangepassword.h"
-JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, JabberAccount * ident, TQWidget * tqparent, const char *name)
- : DlgJabberEditAccountWidget (tqparent, name), KopeteEditAccountWidget (ident)
+JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, JabberAccount * ident, TQWidget * parent, const char *name)
+ : DlgJabberEditAccountWidget (parent, name), KopeteEditAccountWidget (ident)
{
m_protocol = proto;
diff --git a/kopete/protocols/jabber/ui/jabbereditaccountwidget.h b/kopete/protocols/jabber/ui/jabbereditaccountwidget.h
index e1ce2d30..82f56215 100644
--- a/kopete/protocols/jabber/ui/jabbereditaccountwidget.h
+++ b/kopete/protocols/jabber/ui/jabbereditaccountwidget.h
@@ -38,7 +38,7 @@ Q_OBJECT
TQ_OBJECT
public:
- JabberEditAccountWidget (JabberProtocol * proto, JabberAccount *, TQWidget * tqparent = 0, const char *name = 0);
+ JabberEditAccountWidget (JabberProtocol * proto, JabberAccount *, TQWidget * parent = 0, const char *name = 0);
~JabberEditAccountWidget ();
virtual bool validateData ();
virtual Kopete::Account *apply ();
diff --git a/kopete/protocols/jabber/ui/jabberregisteraccount.cpp b/kopete/protocols/jabber/ui/jabberregisteraccount.cpp
index cc7cd0fc..2641ed41 100644
--- a/kopete/protocols/jabber/ui/jabberregisteraccount.cpp
+++ b/kopete/protocols/jabber/ui/jabberregisteraccount.cpp
@@ -47,12 +47,12 @@
#include "jabberchooseserver.h"
#include "dlgjabberregisteraccount.h"
-JabberRegisterAccount::JabberRegisterAccount ( JabberEditAccountWidget *tqparent, const char *name )
- : KDialogBase ( tqparent, name, true, i18n("Register New Jabber Account"),
+JabberRegisterAccount::JabberRegisterAccount ( JabberEditAccountWidget *parent, const char *name )
+ : KDialogBase ( parent, name, true, i18n("Register New Jabber Account"),
KDialogBase::Ok | KDialogBase::Cancel )
{
- mParentWidget = tqparent;
+ mParentWidget = parent;
// setup main dialog
mMainWidget = new DlgJabberRegisterAccount ( this );
@@ -78,12 +78,12 @@ JabberRegisterAccount::JabberRegisterAccount ( JabberEditAccountWidget *tqparent
mSuccess = false;
// get all settings from the main dialog
- mMainWidget->leServer->setText ( tqparent->mServer->text () );
- mMainWidget->leJID->setText ( tqparent->mID->text () );
- mMainWidget->lePassword->setText ( tqparent->mPass->password () );
- // mMainWidget->lePasswordVerify->setText ( tqparent->mPass->password () ); //BUG 114631
- mMainWidget->sbPort->setValue ( tqparent->mPort->value () );
- mMainWidget->cbUseSSL->setChecked ( tqparent->cbUseSSL->isChecked () );
+ mMainWidget->leServer->setText ( parent->mServer->text () );
+ mMainWidget->leJID->setText ( parent->mID->text () );
+ mMainWidget->lePassword->setText ( parent->mPass->password () );
+ // mMainWidget->lePasswordVerify->setText ( parent->mPass->password () ); //BUG 114631
+ mMainWidget->sbPort->setValue ( parent->mPort->value () );
+ mMainWidget->cbUseSSL->setChecked ( parent->cbUseSSL->isChecked () );
// connect buttons to slots, ok is already connected by default
connect ( this, TQT_SIGNAL ( cancelClicked () ), this, TQT_SLOT ( slotDeleteDialog () ) );
@@ -341,7 +341,7 @@ void JabberRegisterAccount::slotRegisterUserDone ()
{
mMainWidget->lblStatusMessage->setText ( i18n ( "Registration successful." ) );
- // save settings to tqparent
+ // save settings to parent
mParentWidget->mServer->setText ( mMainWidget->leServer->text () );
mParentWidget->mID->setText ( mMainWidget->leJID->text () );
mParentWidget->mPass->setPassword ( mMainWidget->lePassword->password () );
diff --git a/kopete/protocols/jabber/ui/jabberregisteraccount.h b/kopete/protocols/jabber/ui/jabberregisteraccount.h
index 5d8b9b5f..74de6387 100644
--- a/kopete/protocols/jabber/ui/jabberregisteraccount.h
+++ b/kopete/protocols/jabber/ui/jabberregisteraccount.h
@@ -39,7 +39,7 @@ Q_OBJECT
TQ_OBJECT
public:
- JabberRegisterAccount ( JabberEditAccountWidget *tqparent = 0, const char *name = 0 );
+ JabberRegisterAccount ( JabberEditAccountWidget *parent = 0, const char *name = 0 );
~JabberRegisterAccount ();
diff --git a/kopete/protocols/jabber/ui/dlgjabbervcard.cpp b/kopete/protocols/jabber/ui/dlgjabbervcard.cpp
index e4139786..2e81801d 100644
--- a/kopete/protocols/jabber/ui/dlgjabbervcard.cpp
+++ b/kopete/protocols/jabber/ui/dlgjabbervcard.cpp
@@ -56,12 +56,12 @@
#include "dlgvcard.h"
/*
* Constructs a dlgJabberVCard which is a child of 'tqparent', with the
* name 'name'
*
*/
-dlgJabberVCard::dlgJabberVCard (JabberAccount *account, JabberBaseContact *contact, TQWidget * tqparent, const char *name)
- : KDialogBase (tqparent, name, false, i18n("Jabber vCard"), Close | User1 | User2, Close, false, i18n("&Save User Info"), i18n("&Fetch vCard") )
+dlgJabberVCard::dlgJabberVCard (JabberAccount *account, JabberBaseContact *contact, TQWidget * parent, const char *name)
+ : KDialogBase (parent, name, false, i18n("Jabber vCard"), Close | User1 | User2, Close, false, i18n("&Save User Info"), i18n("&Fetch vCard") )
{
m_account = account;
@@ -56,12 +56,12 @@
#include "dlgvcard.h"
/*
- * Constructs a dlgJabberVCard which is a child of 'tqparent', with the
+ * Constructs a dlgJabberVCard which is a child of 'parent', with the
* name 'name'
*